pub struct RegexError {
pub position: usize,
pub message: String,
}Expand description
Summary
RegexError is an alias of a couple (usize, String).
The first element is the position at which the error occured,
and the second one is a description of the said error.
Fields
position: usizemessage: StringTrait Implementations
Sourceimpl Debug for RegexError
impl Debug for RegexError
Sourceimpl PartialEq for RegexError
impl PartialEq for RegexError
impl Eq for RegexError
impl StructuralPartialEq for RegexError